==> fwobac-1.2.tar.gz: fwobac-1.2/fdk_hmac.h <==
/* $Id: fdk_hmac.h,v 1.5 2017/08/05 12:05:09 rlr Exp $ */

/*
 * Copyright (c) 2016, 2017 Ross L Richardson <rueda@rlr.id.au>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


/*
 * Module providing file digest-keyed HMAC functions.
 * 
 * The current implementation uses HMAC-SHA256.  The key is the SHA256
 * message digest of the specified file.
 */


#include <stdbool.h>
#include <stddef.h>


#ifndef _FDK_HMAC_H_
#define _FDK_HMAC_H_

#define FDK_HMAC_BIN_SIZE  32  /* size of binary HMAC */
#define FDK_HMAC_B64_LEN   44  /* length of base64-encoded HMAC */
#define FDK_HMAC_B64_SIZE  (FDK_HMAC_B64_LEN + 1)


/*
 * void
 * fdk_hmac_generate(const char *kfp, const void *m, size_t m_sz,
 *     unsigned char *hmac, size_t *hmac_sz);
 *
 * Generates binary HMAC of key (derived from file specified by kfp) and
 * message m (of length m_sz), storing result in hmac and setting hmac_sz
 * to the size of the result.  On error, hmac_sz is set to zero.
 */
void
fdk_hmac_generate(const char *, const void *, size_t, unsigned char *,
    size_t *);


/*
 * void
 * fdk_hmac_generate_b64(const char *kfp, const void *m, size_t m_sz,
 *     char *b64);
 *
 * Generates HMAC of key (derived from file specified by kfp) and message m (of
 * length m_sz), storing result base64-encoded in b64 (which must be of size no
 * less than FDK_HMAC_B64_SIZE).  On failure, sets b64 to the empty string.
 */
void
fdk_hmac_generate_b64(const char *, const void *, size_t, char *);


/*
 * bool
 * fdk_hmac_validate(const char *kfp, const void *m, size_t m_sz,
 *     const unsigned char *d);
 *
 * Calculates HMAC as for fdk_hmac_generate_b64(), and performs timing-safe
 * comparison of that value and that specified by d.  Returns non-zero if and
 * only if no error occurs and the values match.
 */
bool
fdk_hmac_validate(const char *, const void *, size_t, const unsigned char *);


/*
 * bool
 * fdk_hmac_validate_b64(const char *kfp, const void *m, size_t m_sz,
 *     const char *b);
 *
 * Base64-encoding equivalent of fdk_hmac_validate().
 */
bool
fdk_hmac_validate_b64(const char *, const void *, size_t, const char *);


#endif /* !_FDK_HMAC_H_ */

==> fwobac-2.1.tar.gz: fwobac-2.1/fdk_hmac.h <==
/* $Id: fdk_hmac.h,v 1.10 2018/06/19 04:42:43 rlr Exp $ */

/*
 * Copyright (c) 2016, 2017, 2018 Ross L Richardson <rueda@rlr.id.au>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


/*
 * Module providing file digest-keyed HMAC functions.
 *
 * The current implementation uses HMAC-SHA256.  The key is the SHA256
 * message digest of the specified file.
 */


#include <stdbool.h>
#include <stddef.h>


#ifndef _FDK_HMAC_H_
#define _FDK_HMAC_H_

#define FDK_HMAC_BIN_SIZE  32  /* size of binary HMAC */
#define FDK_HMAC_B64_LEN   44  /* length of base64-encoded HMAC */
#define FDK_HMAC_B64_SIZE  (FDK_HMAC_B64_LEN + 1)


/*
 * void
 * fdk_hmac_generate(const char *kfp, const void *m, size_t m_sz,
 *     unsigned char *hmac, size_t *hmac_sz);
 *
 * Generates binary HMAC of key (derived from file specified by kfp) and
 * message m (of length m_sz), storing result in hmac and setting hmac_sz
 * to the size of the result.  On error, hmac_sz is set to zero.
 */
void	 fdk_hmac_generate(const char *, const void *, size_t, unsigned char *,
    size_t *);


/*
 * void
 * fdk_hmac_generate_b64(const char *kfp, const void *m, size_t m_sz,
 *     char *b64);
 *
 * Generates HMAC of key (derived from file specified by kfp) and message m (of
 * length m_sz), storing result base64-encoded in b64 (which must be of size no
 * less than FDK_HMAC_B64_SIZE).  On failure, sets b64 to the empty string.
 */
void	 fdk_hmac_generate_b64(const char *, const void *, size_t, char *);


/*
 * bool
 * fdk_hmac_validate(const char *kfp, const void *m, size_t m_sz,
 *     const unsigned char *d);
 *
 * Calculates HMAC as for fdk_hmac_generate_b64(), and performs timing-safe
 * comparison of that value and that specified by d.  Returns non-zero if and
 * only if no error occurs and the values match.
 */
bool	 fdk_hmac_validate(const char *, const void *, size_t,
    const unsigned char *);


/*
 * bool
 * fdk_hmac_validate_b64(const char *kfp, const void *m, size_t m_sz,
 *     const char *b);
 *
 * Base64-encoding equivalent of fdk_hmac_validate().
 */
bool	 fdk_hmac_validate_b64(const char *, const void *, size_t,
    const char *);


#endif /* !_FDK_HMAC_H_ */
